@@ -114,51 +114,64 @@ function DesktopEnvironment() {
 
       if [ "$1" == "gnome" ]; then
             echo "gnome"
-            eval $terminal "sudo pacman -S gnome-common gnome-font-viewer gnome-keyring gnome-terminal qt5-styleplugins qt5ct gnome-online-accounts libgnome-keyring --needed --noconfirm"
+            # eval $terminal "sudo pacman -S gnome-common gnome-font-viewer gnome-keyring gnome-terminal qt5-styleplugins qt5ct gnome-online-accounts libgnome-keyring --needed --noconfirm"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-gnome --noconfirm"
       elif [ "$1" == "apricity" ]; then
             echo "apricity"
             # Download and install apricity-theme from the main RebornOS repository
             curl -o rebornos.txt http://repo.rebornos.org/RebornOS/
             themeFile=$(grep "apricity-theme" rebornos.txt | cut -f2 -d "\"" | cut -d "\"" -f1 | grep -v "sig")
             # Install packages with only one pkexec dialog
-            eval $terminal "sudo pacman -U $themeFile --needed --noconfirm"
+            # eval $terminal "sudo pacman -U $themeFile --needed --noconfirm"
+            eval xterm -e "sudo pacman -U $themeFile --noconfirm"
             rm -f rebornos.txt
       elif [ "$1" == "cinnamon" ]; then
             echo "cinnamon"
-            eval $terminal "sudo pacman -S $1 muffin nemo-fileroller nemo-share nemo-preview nemo-seahorse seahorse gnome-common gnome-font-viewer gnome-keyring gnome-terminal qt5-styleplugins qt5ct gnome-online-accounts libgnome-keyring --needed --noconfirm"
-            eval $terminal "sudo yay -S mint-themes mint-x-icons mint-y-icons mintlocale mintstick --noconfirm --needed"
+            # eval $terminal "sudo pacman -S $1 muffin nemo-fileroller nemo-share nemo-preview nemo-seahorse seahorse gnome-common gnome-font-viewer gnome-keyring gnome-terminal qt5-styleplugins qt5ct gnome-online-accounts libgnome-keyring --needed --noconfirm"
+            # eval $terminal "sudo yay -S mint-themes mint-x-icons mint-y-icons mintlocale mintstick --noconfirm --needed"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-cinnamon --noconfirm"
       elif [ "$1" == "deepin" ]; then
             echo "deepin"
-            eval $terminal "sudo pacman -S redshift deepin deepin-extra noto-fonts noto-fonts-emoji unicode-character-database blueman --needed --noconfirm"
-            eval $terminal "sudo pacman -Rdd qt5ct --noconfirm"
+            # eval $terminal "sudo pacman -S redshift deepin deepin-extra noto-fonts noto-fonts-emoji unicode-character-database blueman --needed --noconfirm"
+            # eval $terminal "sudo pacman -Rdd qt5ct --noconfirm"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-deepin --noconfirm"
       elif [ "$1" == "budgie" ]; then
             echo "budgie"
-            eval $terminal "sudo pacman -S bugdie-desktop budgie-extras gnome gnome-tweaks --needed --noconfirm"
+            # eval $terminal "sudo pacman -S bugdie-desktop budgie-extras gnome gnome-tweaks --needed --noconfirm"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-budgie --noconfirm"
       elif [ "$1" == "enlightenment" ]; then
             echo "enlightenment"
-            eval $terminal "sudo pacman -S enlightenment connman qt5ct terminology xdg-user-dirs-gtk --needed --noconfirm"
+            # eval $terminal "sudo pacman -S enlightenment connman qt5ct terminology xdg-user-dirs-gtk --needed --noconfirm"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-enlightenment --noconfirm"
       elif [ "$1" == "i3" ]; then
             echo "i3"
-            eval $terminal "sudo pacman -S i3 dmenu file-roller network-manager-applet networkmanager-openvpn networkmanager-pptp nitrogen pcmanfm polkit-gnome xdg-user-dirs-gtk notify-osd python-pysmbc lxappearance-gtk3 lxinput-gtk3 awesome-terminal-fonts --needed --noconfirm"
+            # eval $terminal "sudo pacman -S i3 dmenu file-roller network-manager-applet networkmanager-openvpn networkmanager-pptp nitrogen pcmanfm polkit-gnome xdg-user-dirs-gtk notify-osd python-pysmbc lxappearance-gtk3 lxinput-gtk3 awesome-terminal-fonts --needed --noconfirm"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-i3 --noconfirm"
       elif [ "$1" == "plasma" ]; then
             echo "plasma"
-            eval $terminal "sudo pacman -S gnu-free-fonts spectacle kcolorchooser sshfs gwenview plasma kf5 kdebase --needed --noconfirm"
+            # eval $terminal "sudo pacman -S gnu-free-fonts spectacle kcolorchooser sshfs gwenview plasma kf5 kdebase --needed --noconfirm"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-kde --noconfirm"
       elif [ "$1" == "lxqt" ]; then
             echo "lxqt"
-            eval $terminal "sudo pacman -S lxqt packagekit-qt5 xdg-user-dirs libstatgrab libsysstat network-manager-applet file-roller unace xscreensaver xautolock lxqt-build-tools --needed --noconfirm"
+            # eval $terminal "sudo pacman -S lxqt packagekit-qt5 xdg-user-dirs libstatgrab libsysstat network-manager-applet file-roller unace xscreensaver xautolock lxqt-build-tools --needed --noconfirm"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-lxqt --noconfirm"
       elif [ "$1" == "mate" ]; then
             echo "mate"
-            eval $terminal "sudo pacman -S mate mate-extra gnome-keyring network-manager-applet networkmanager-applet xdg-user-dirs-gtk mate-tweak qt5ct"
+            # eval $terminal "sudo pacman -S mate mate-extra gnome-keyring network-manager-applet networkmanager-applet xdg-user-dirs-gtk mate-tweak qt5ct"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-mate --noconfirm"
       elif [ "$1" == "openbox" ]; then
             echo "openbox"
-            eval $terminal "sudo pacman -S lxde file-roller arandr openbox-menu compton lxmenu-data lxappearance-obconf-gtk3 obkey oblogout networkmanager-openvpn networkmanager-pptp notify-osd nitrogen mousepad obconf parcellite polkit qt5ct scrot tint2 volumeicon udiskie xdg-user-dirs-gtk openbox-theme --needed --noconfirm"
+            # eval $terminal "sudo pacman -S lxde file-roller arandr openbox-menu compton lxmenu-data lxappearance-obconf-gtk3 obkey oblogout networkmanager-openvpn networkmanager-pptp notify-osd nitrogen mousepad obconf parcellite polkit qt5ct scrot tint2 volumeicon udiskie xdg-user-dirs-gtk openbox-theme --needed --noconfirm"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-openbox --noconfirm"
       elif [ "$1" == "xfce" ]; then
             echo "xfce"
-            eval $terminal "sudo pacman -S xfce4 xfce4-goodies file-roller gtk-engine-murrine network-manager-applet networkmanager-openvpn networkmanager-pptp polkit-gnome qt5ct xdg-user-dirs-gtk ristretto xfce4-whiskermenu-plugin gnome-font-viewer catfish libgit2-glib --needed --noconfirm"
+            # eval $terminal "sudo pacman -S xfce4 xfce4-goodies file-roller gtk-engine-murrine network-manager-applet networkmanager-openvpn networkmanager-pptp polkit-gnome qt5ct xdg-user-dirs-gtk ristretto xfce4-whiskermenu-plugin gnome-font-viewer catfish libgit2-glib --needed --noconfirm"
+            eval xterm -e "sudo pacman -S rebornos-cosmic-xfce --noconfirm"
       elif [ "$1" == "pantheon" ]; then
             echo "pantheon"
-            eval $terminal "yay -S pantheon-session-git gala-git wingpanel-indicator-datetime-git wingpanel-indicator-session-git wingpanel-git cerbere-git pantheon-applications-menu-git switchboard-git pantheon-dpms-helper-git pantheon-default-settings-git gnome-settings-daemon-elementary pantheon-print-git pantheon-polkit-agent-git --noconfirm"
-            pkexec pacman -S pantheon bzr --needed --noconfirm
+            # eval $terminal "yay -S pantheon-session-git gala-git wingpanel-indicator-datetime-git wingpanel-indicator-session-git wingpanel-git cerbere-git pantheon-applications-menu-git switchboard-git pantheon-dpms-helper-git pantheon-default-settings-git gnome-settings-daemon-elementary pantheon-print-git pantheon-polkit-agent-git --noconfirm"
+            # pkexec pacman -S pantheon bzr --needed --noconfirm
+            eval xterm -e "sudo pacman -S rebornos-cosmic-pantheon --noconfirm"
       fi
 }
 
