@@ -39,12 +39,19 @@ except:
 # Create Handlers (Triggers) for each item
 class Handler:
     def __init__(self):
-        # Create settings file is it does not already exist, as well as declare the self.settings array
+        # Create settings file if it does not already exist, as well as declare the self.settings array
         if not os.path.isfile(settingsFile):
             with open(settingsFile, 'w+') as outfile:
-                self.settings = [[""]]
-                outfile.write(json.dumps(self.settings))
-                os.system('bash ' + bashFile + ' Install "' + packageFile + '"' + ' "' + workingDirectory + '"')
+                self.settings = {
+                    "terminal": "",
+                    "chosen_date": {
+                        "day": 0,
+                        "month": 0,
+                        "year": 0
+                    }
+                }
+                with open(settingsFile, 'w+') as outfile:
+                    outfile.write(json.dumps(self.settings, indent = 4))
         else:
             with open(settingsFile) as outfile:
                 self.settings = json.load(outfile)
@@ -64,51 +71,51 @@ class Handler:
             chosenTerminal = model[tree_iter][0]
             if chosenTerminal == "Deepin Terminal":
                 print("Deepin Terminal successfully selected!")
-                self.settings[0]=["deepin-terminal --execute "]
+                self.settings["terminal"]= "deepin-terminal --execute "
                 with open(settingsFile, 'w+') as outfile:
-                    outfile.write(json.dumps(self.settings))
+                    outfile.write(json.dumps(self.settings, indent = 4))
 
             elif chosenTerminal == "GNOME Terminal":
                 print("GNOME Terminal successfully selected!")
-                self.settings[0]=["gnome-terminal -- "]
+                self.settings["terminal"] = "gnome-terminal -- "
                 with open(settingsFile, 'w+') as outfile:
-                    outfile.write(json.dumps(self.settings))
+                    outfile.write(json.dumps(self.settings, indent = 4))
 
             elif chosenTerminal == "Konsole":
                 print("Konsole Terminal successfully selected!")
-                self.settings[0]=["konsole -e "]
+                self.settings["terminal"] = "konsole -e "
                 with open(settingsFile, 'w+') as outfile:
-                    outfile.write(json.dumps(self.settings))
+                    outfile.write(json.dumps(self.settings, indent = 4))
 
             elif chosenTerminal == "Xterm":
                 print("Xterm Terminal successfully selected!")
-                self.settings[0]=["xterm -e "]
+                self.settings["terminal"] = "xterm -e "
                 with open(settingsFile, 'w+') as outfile:
-                    outfile.write(json.dumps(self.settings))
+                    outfile.write(json.dumps(self.settings, indent = 4))
 
             elif chosenTerminal == "Terminology":
                 print("Terminology successfully selected!")
-                self.settings[0]=["terminology -e "]
+                self.settings["terminal"] = "terminology -e "
                 with open(settingsFile, 'w+') as outfile:
-                    outfile.write(json.dumps(self.settings))
+                    outfile.write(json.dumps(self.settings, indent = 4))
 
             elif chosenTerminal == "LXTerminal":
                 print("LXTerminal successfully selected!")
-                self.settings[0]=["lxterminal -e "]
+                self.settings["terminal"] = "lxterminal -e "
                 with open(settingsFile, 'w+') as outfile:
-                    outfile.write(json.dumps(self.settings))
+                    outfile.write(json.dumps(self.settings, indent = 4))
 
             elif chosenTerminal == "MATE Terminal":
                 print("MATE Terminal successfully selected!")
-                self.settings[0]=["mate-terminal -e "]
+                self.settings["terminal"] = "mate-terminal -e "
                 with open(settingsFile, 'w+') as outfile:
-                    outfile.write(json.dumps(self.settings))
+                    outfile.write(json.dumps(self.settings, indent = 4))
 
             elif chosenTerminal == "XFCE4 Terminal":
                 print("XFCE4 Terminal successfully selected!")
-                self.settings[0]=["xfce4-terminal -e "]
+                self.settings["terminal"] = "xfce4-terminal -e "
                 with open(settingsFile, 'w+') as outfile:
-                    outfile.write(json.dumps(self.settings))
+                    outfile.write(json.dumps(self.settings, indent = 4))
 
             else:
                 Notify.Notification.new("ERROR! Abort! Abort!!!").show()
